@@ -20,11 +20,23 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any
+
 import github.GithubObject
 import github.NamedUser
 import github.RequiredPullRequestReviews
 import github.RequiredStatusChecks
 import github.Team
+from github.GithubObject import Attribute, NotSet, Opt, is_defined
+from github.PaginatedList import PaginatedList
+
+if TYPE_CHECKING:
+    from github.NamedUser import NamedUser
+    from github.RequiredPullRequestReviews import RequiredPullRequestReviews
+    from github.RequiredStatusChecks import RequiredStatusChecks
+    from github.Team import Team
 
 
 class BranchProtection(github.GithubObject.CompletableGithubObject):
@@ -32,73 +44,59 @@ class BranchProtection(github.GithubObject.CompletableGithubObject):
     This class represents Branch Protection. The reference can be found here https://docs.github.com/en/rest/reference/repos#get-branch-protection
     """
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.get__repr__({"url": self._url.value})
 
+    def _initAttributes(self) -> None:
+        self._url: Attribute[str] = NotSet
+        self._required_status_checks: Attribute[RequiredStatusChecks] = NotSet
+        self._enforce_admins: Attribute[bool] = NotSet
+        self._required_linear_history: Attribute[bool] = github.GithubObject.NotSet
+        self._required_pull_request_reviews: Attribute[RequiredPullRequestReviews] = NotSet
+        self._user_push_restrictions: Opt[str] = NotSet
+        self._team_push_restrictions: Opt[str] = NotSet
+
     @property
-    def url(self):
-        """
-        :type: string
-        """
+    def url(self) -> str:
         self._completeIfNotSet(self._url)
         return self._url.value
 
     @property
-    def required_status_checks(self):
-        """
-        :type: :class:`github.RequiredStatusChecks.RequiredStatusChecks`
-        """
+    def required_status_checks(self) -> RequiredStatusChecks:
         self._completeIfNotSet(self._required_status_checks)
         return self._required_status_checks.value
 
     @property
-    def enforce_admins(self):
-        """
-        :type: bool
-        """
+    def enforce_admins(self) -> bool:
         self._completeIfNotSet(self._enforce_admins)
         return self._enforce_admins.value
 
     @property
-    def required_pull_request_reviews(self):
-        """
-        :type: :class:`github.RequiredPullRequestReviews.RequiredPullRequestReviews`
-        """
+    def required_linear_history(self) -> bool:
+        self._completeIfNotSet(self._required_linear_history)
+        return self._required_linear_history.value
+
+    @property
+    def required_pull_request_reviews(self) -> RequiredPullRequestReviews:
         self._completeIfNotSet(self._required_pull_request_reviews)
         return self._required_pull_request_reviews.value
 
-    def get_user_push_restrictions(self):
-        """
-        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
-        """
-        if self._user_push_restrictions is github.GithubObject.NotSet:
+    def get_user_push_restrictions(self) -> PaginatedList[NamedUser] | None:
+        if not is_defined(self._user_push_restrictions):
             return None
-        return github.PaginatedList.PaginatedList(
+        return PaginatedList(
             github.NamedUser.NamedUser,
             self._requester,
             self._user_push_restrictions,
             None,
         )
 
-    def get_team_push_restrictions(self):
-        """
-        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Team.Team`
-        """
-        if self._team_push_restrictions is github.GithubObject.NotSet:
+    def get_team_push_restrictions(self) -> PaginatedList[Team] | None:
+        if not is_defined(self._team_push_restrictions):
             return None
-        return github.PaginatedList.PaginatedList(
-            github.Team.Team, self._requester, self._team_push_restrictions, None
-        )
+        return github.PaginatedList.PaginatedList(github.Team.Team, self._requester, self._team_push_restrictions, None)
 
-    def _initAttributes(self):
-        self._url = github.GithubObject.NotSet
-        self._required_status_checks = github.GithubObject.NotSet
-        self._enforce_admins = github.GithubObject.NotSet
-        self._required_pull_request_reviews = github.GithubObject.NotSet
-        self._user_push_restrictions = github.GithubObject.NotSet
-        self._team_push_restrictions = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
         if "required_status_checks" in attributes:  # pragma no branch
@@ -107,14 +105,14 @@ class BranchProtection(github.GithubObject.CompletableGithubObject):
                 attributes["required_status_checks"],
             )
         if "enforce_admins" in attributes:  # pragma no branch
-            self._enforce_admins = self._makeBoolAttribute(
-                attributes["enforce_admins"]["enabled"]
-            )
+            self._enforce_admins = self._makeBoolAttribute(attributes["enforce_admins"]["enabled"])
         if "required_pull_request_reviews" in attributes:  # pragma no branch
             self._required_pull_request_reviews = self._makeClassAttribute(
                 github.RequiredPullRequestReviews.RequiredPullRequestReviews,
                 attributes["required_pull_request_reviews"],
             )
+        if "required_linear_history" in attributes:  # pragma no branch
+            self._required_linear_history = self._makeBoolAttribute(attributes["required_linear_history"]["enabled"])
         if "restrictions" in attributes:  # pragma no branch
             self._user_push_restrictions = attributes["restrictions"]["users_url"]
             self._team_push_restrictions = attributes["restrictions"]["teams_url"]
