@@ -27,54 +27,62 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+from typing import Any, Dict
 
-import github.GithubObject
+from github.GithubObject import Attribute, NonCompletableGithubObject, NotSet
 
 
-class Permissions(github.GithubObject.NonCompletableGithubObject):
+class Permissions(NonCompletableGithubObject):
     """
     This class represents Permissions
     """
 
-    def __repr__(self):
+    def _initAttributes(self) -> None:
+        self._admin: Attribute[bool] = NotSet
+        self._maintain: Attribute[bool] = NotSet
+        self._pull: Attribute[bool] = NotSet
+        self._push: Attribute[bool] = NotSet
+        self._triage: Attribute[bool] = NotSet
+
+    def __repr__(self) -> str:
         return self.get__repr__(
             {
                 "admin": self._admin.value,
+                "maintain": self._maintain.value,
                 "pull": self._pull.value,
                 "push": self._push.value,
+                "triage": self._triage.value,
             }
         )
 
     @property
-    def admin(self):
-        """
-        :type: bool
-        """
+    def admin(self) -> bool:
         return self._admin.value
 
     @property
-    def pull(self):
-        """
-        :type: bool
-        """
+    def maintain(self) -> bool:
+        return self._maintain.value
+
+    @property
+    def pull(self) -> bool:
         return self._pull.value
 
     @property
-    def push(self):
-        """
-        :type: bool
-        """
+    def push(self) -> bool:
         return self._push.value
 
-    def _initAttributes(self):
-        self._admin = github.GithubObject.NotSet
-        self._pull = github.GithubObject.NotSet
-        self._push = github.GithubObject.NotSet
+    @property
+    def triage(self) -> bool:
+        return self._triage.value
 
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: Dict[str, Any]) -> None:
         if "admin" in attributes:  # pragma no branch
             self._admin = self._makeBoolAttribute(attributes["admin"])
+        if "maintain" in attributes:  # pragma no branch
+            self._maintain = self._makeBoolAttribute(attributes["maintain"])
         if "pull" in attributes:  # pragma no branch
             self._pull = self._makeBoolAttribute(attributes["pull"])
         if "push" in attributes:  # pragma no branch
             self._push = self._makeBoolAttribute(attributes["push"])
+        if "triage" in attributes:  # pragma no branch
+            self._triage = self._makeBoolAttribute(attributes["triage"])
