@@ -19,153 +19,130 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+from __future__ import annotations
+
+from datetime import datetime
+from typing import Any
 
 import github.GithubObject
 import github.Project
 import github.ProjectCard
+from github.GithubObject import Attribute, CompletableGithubObject, NotSet, Opt
+from github.PaginatedList import PaginatedList
 
 from . import Consts
 
 
-class ProjectColumn(github.GithubObject.CompletableGithubObject):
+class ProjectColumn(CompletableGithubObject):
     """
-    This class represents Project Columns. The reference can be found here http://developer.github.com/v3/projects/columns
+    This class represents Project Columns. The reference can be found here https://docs.github.com/en/rest/reference/projects#columns
     """
 
-    def __repr__(self):
+    def _initAttributes(self) -> None:
+        self._cards_url: Attribute[str] = NotSet
+        self._created_at: Attribute[datetime] = NotSet
+        self._id: Attribute[int] = NotSet
+        self._name: Attribute[str] = NotSet
+        self._node_id: Attribute[str] = NotSet
+        self._project_url: Attribute[str] = NotSet
+        self._updated_at: Attribute[datetime] = NotSet
+        self._url: Attribute[str] = NotSet
+
+    def __repr__(self) -> str:
         return self.get__repr__({"name": self._name.value})
 
     @property
-    def cards_url(self):
-        """
-        :type: string
-        """
+    def cards_url(self) -> str:
         return self._cards_url.value
 
     @property
-    def created_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def created_at(self) -> datetime:
         return self._created_at.value
 
     @property
-    def id(self):
-        """
-        :type: integer
-        """
+    def id(self) -> int:
         return self._id.value
 
     @property
-    def name(self):
-        """
-        :type: string
-        """
+    def name(self) -> str:
         return self._name.value
 
     @property
-    def node_id(self):
-        """
-        :type: string
-        """
+    def node_id(self) -> str:
         return self._node_id.value
 
     @property
-    def project_url(self):
-        """
-        :type: string
-        """
+    def project_url(self) -> str:
         return self._project_url.value
 
     @property
-    def updated_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def updated_at(self) -> datetime:
         return self._updated_at.value
 
     @property
-    def url(self):
-        """
-        :type: string
-        """
+    def url(self) -> str:
         return self._url.value
 
-    def get_cards(self, archived_state=github.GithubObject.NotSet):
+    def get_cards(self, archived_state: Opt[str] = NotSet) -> PaginatedList[github.ProjectCard.ProjectCard]:
         """
-        :calls: `GET /projects/columns/:column_id/cards <https://developer.github.com/v3/projects/cards/#list-project-cards>`_
-        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.ProjectCard.ProjectCard`
-        :param archived_state: string
+        :calls: `GET /projects/columns/{column_id}/cards <https://docs.github.com/en/rest/reference/projects#list-project-cards>`_
         """
-        assert archived_state is github.GithubObject.NotSet or isinstance(
-            archived_state, str
-        ), archived_state
+        assert archived_state is NotSet or isinstance(archived_state, str), archived_state
 
         url_parameters = dict()
-        if archived_state is not github.GithubObject.NotSet:
+        if archived_state is not NotSet:
             url_parameters["archived_state"] = archived_state
 
-        return github.PaginatedList.PaginatedList(
+        return PaginatedList(
             github.ProjectCard.ProjectCard,
             self._requester,
-            self.url + "/cards",
+            f"{self.url}/cards",
             url_parameters,
             {"Accept": Consts.mediaTypeProjectsPreview},
         )
 
     def create_card(
         self,
-        note=github.GithubObject.NotSet,
-        content_id=github.GithubObject.NotSet,
-        content_type=github.GithubObject.NotSet,
-    ):
+        note: Opt[str] = NotSet,
+        content_id: Opt[int] = NotSet,
+        content_type: Opt[str] = NotSet,
+    ) -> github.ProjectCard.ProjectCard:
         """
-        :calls: `POST /projects/columns/:column_id/cards <https://developer.github.com/v3/projects/cards/#create-a-project-card>`_
-        :param note: string
-        :param content_id: integer
-        :param content_type: string
-
-        :rtype :class:`github.ProjectCard.ProjectCard`:
+        :calls: `POST /projects/columns/{column_id}/cards <https://docs.github.com/en/rest/reference/projects#create-a-project-card>`_
         """
         if isinstance(note, str):
-            assert content_id is github.GithubObject.NotSet, content_id
-            assert content_type is github.GithubObject.NotSet, content_type
-            post_parameters = {"note": note}
+            assert content_id is NotSet, content_id
+            assert content_type is NotSet, content_type
+            post_parameters: dict[str, Any] = {"note": note}
         else:
-            assert note is github.GithubObject.NotSet, note
+            assert note is NotSet, note
             assert isinstance(content_id, int), content_id
             assert isinstance(content_type, str), content_type
             post_parameters = {"content_id": content_id, "content_type": content_type}
 
         import_header = {"Accept": Consts.mediaTypeProjectsPreview}
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/cards", headers=import_header, input=post_parameters
-        )
-        return github.ProjectCard.ProjectCard(
-            self._requester, headers, data, completed=True
+            "POST", f"{self.url}/cards", headers=import_header, input=post_parameters
         )
+        return github.ProjectCard.ProjectCard(self._requester, headers, data, completed=True)
 
-    def move(self, position):
+    def move(self, position: str) -> bool:
         """
-        :calls: `POST POST /projects/columns/:column_id/moves <https://developer.github.com/v3/projects/columns/#move-a-project-column>`_
-        :param position: string
-
-        :rtype: bool
+        :calls: `POST POST /projects/columns/{column_id}/moves <https://docs.github.com/en/rest/reference/projects#move-a-project-column>`_
         """
         assert isinstance(position, str), position
         post_parameters = {"position": position}
         status, _, _ = self._requester.requestJson(
             "POST",
-            self.url + "/moves",
+            f"{self.url}/moves",
             input=post_parameters,
             headers={"Accept": Consts.mediaTypeProjectsPreview},
         )
         return status == 201
 
-    def delete(self):
+    def delete(self) -> bool:
         """
-        :calls: `DELETE /projects/columns/:column_id <https://developer.github.com/v3/projects/columns/#delete-a-project-column>`_
-        :rtype: bool
+        :calls: `DELETE /projects/columns/{column_id} <https://docs.github.com/en/rest/reference/projects#delete-a-project-column>`_
         """
         status, _, _ = self._requester.requestJson(
             "DELETE",
@@ -174,11 +151,9 @@ class ProjectColumn(github.GithubObject.CompletableGithubObject):
         )
         return status == 204
 
-    def edit(self, name):
+    def edit(self, name: str) -> None:
         """
-        :calls: `PATCH /projects/columns/:column_id <https://developer.github.com/v3/projects/columns/#update-a-project-column>`_
-        :param name: string
-        :rtype: None
+        :calls: `PATCH /projects/columns/{column_id} <https://docs.github.com/en/rest/reference/projects#update-an-existing-project-column>`_
         """
         assert isinstance(name, str), name
         patch_parameters = {"name": name}
@@ -192,17 +167,7 @@ class ProjectColumn(github.GithubObject.CompletableGithubObject):
 
         self._useAttributes(data)
 
-    def _initAttributes(self):
-        self._cards_url = github.GithubObject.NotSet
-        self._created_at = github.GithubObject.NotSet
-        self._id = github.GithubObject.NotSet
-        self._name = github.GithubObject.NotSet
-        self._node_id = github.GithubObject.NotSet
-        self._project_url = github.GithubObject.NotSet
-        self._updated_at = github.GithubObject.NotSet
-        self._url = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "cards_url" in attributes:  # pragma no branch
             self._cards_url = self._makeStringAttribute(attributes["cards_url"])
         if "created_at" in attributes:  # pragma no branch
