@@ -23,41 +23,43 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+from __future__ import annotations
 
-import github
+from datetime import datetime
+from typing import TYPE_CHECKING, Any
+
+import github.NamedUser
+from github.GithubObject import Attribute, NonCompletableGithubObject, NotSet
+
+if TYPE_CHECKING:
+    from github.NamedUser import NamedUser
 
 
-class Stargazer(github.GithubObject.NonCompletableGithubObject):
+class Stargazer(NonCompletableGithubObject):
     """
-    This class represents Stargazers. The reference can be found here https://docs.github.com/en/rest/reference/activity/starring#alternative-response-with-star-creation-timestamps
+    This class represents Stargazers. The reference can be found here https://docs.github.com/en/rest/reference/activity#starring
     """
 
-    def __repr__(self):
-        return self.get__repr__({"user": self._user.value._login.value})
+    def _initAttributes(self) -> None:
+        self._starred_at: Attribute[datetime] = NotSet
+        self._user: Attribute[NamedUser] = NotSet
+        self._url: Attribute[str] = NotSet
+
+    def __repr__(self) -> str:
+        # this is not a type error, just we didn't type `NamedUser` yet.
+        # enable type checker here after we typed attribute of `NamedUser`
+        return self.get__repr__({"user": self._user.value._login.value})  # type: ignore
 
     @property
-    def starred_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def starred_at(self) -> datetime:
         return self._starred_at.value
 
     @property
-    def user(self):
-        """
-        :type: :class:`github.NamedUser`
-        """
+    def user(self) -> NamedUser:
         return self._user.value
 
-    def _initAttributes(self):
-        self._starred_at = github.GithubObject.NotSet
-        self._user = github.GithubObject.NotSet
-        self._url = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "starred_at" in attributes:
             self._starred_at = self._makeDatetimeAttribute(attributes["starred_at"])
         if "user" in attributes:
-            self._user = self._makeClassAttribute(
-                github.NamedUser.NamedUser, attributes["user"]
-            )
+            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
