@@ -19,182 +19,131 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+from __future__ import annotations
 
+from datetime import datetime
+from typing import Any
 
 import github.GithubObject
 import github.NamedUser
+from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 
 
-class TeamDiscussion(github.GithubObject.CompletableGithubObject):
+class TeamDiscussion(CompletableGithubObject):
     """
-    This class represents TeamDiscussions. The reference can be found here https://developer.github.com/v3/teams/discussions/
+    This class represents TeamDiscussions. The reference can be found here https://docs.github.com/en/rest/reference/teams#discussions
     """
 
-    def __repr__(self):
-        return self.get__repr__(
-            {"number": self._number.value, "title": self._title.value}
-        )
+    def _initAttributes(self) -> None:
+        self._author: Attribute[github.NamedUser.NamedUser] = NotSet
+        self._body: Attribute[str] = NotSet
+        self._body_html: Attribute[str] = NotSet
+        self._body_version: Attribute[str] = NotSet
+        self._comments_count: Attribute[int] = NotSet
+        self._comments_url: Attribute[str] = NotSet
+        self._created_at: Attribute[datetime] = NotSet
+        self._html_url: Attribute[str] = NotSet
+        self._last_edited_at: Attribute[datetime] = NotSet
+        self._node_id: Attribute[str] = NotSet
+        self._number: Attribute[int] = NotSet
+        self._pinned: Attribute[bool] = NotSet
+        self._private: Attribute[bool] = NotSet
+        self._team_url: Attribute[str] = NotSet
+        self._title: Attribute[str] = NotSet
+        self._updated_at: Attribute[datetime] = NotSet
+        self._url: Attribute[str] = NotSet
+
+    def __repr__(self) -> str:
+        return self.get__repr__({"number": self._number.value, "title": self._title.value})
 
     @property
-    def author(self):
-        """
-        :type: :class:`github.NamedUser.NamedUser`
-        """
+    def author(self) -> github.NamedUser.NamedUser:
         self._completeIfNotSet(self._author)
         return self._author.value
 
     @property
-    def body(self):
-        """
-        :type: string
-        """
+    def body(self) -> str:
         self._completeIfNotSet(self._body)
         return self._body.value
 
     @property
-    def body_html(self):
-        """
-        :type: string
-        """
+    def body_html(self) -> str:
         self._completeIfNotSet(self._body_html)
         return self._body_html.value
 
     @property
-    def body_version(self):
-        """
-        :type: string
-        """
+    def body_version(self) -> str:
         self._completeIfNotSet(self._body_version)
         return self._body_version.value
 
     @property
-    def comments_count(self):
-        """
-        :type: integer
-        """
+    def comments_count(self) -> int:
         self._completeIfNotSet(self._comments_count)
         return self._comments_count.value
 
     @property
-    def comments_url(self):
-        """
-        :type: string
-        """
+    def comments_url(self) -> str:
         self._completeIfNotSet(self._comments_url)
         return self._comments_url.value
 
     @property
-    def created_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def created_at(self) -> datetime:
         self._completeIfNotSet(self._created_at)
         return self._created_at.value
 
     @property
-    def html_url(self):
-        """
-        :type: string
-        """
+    def html_url(self) -> str:
         self._completeIfNotSet(self._html_url)
         return self._html_url.value
 
     @property
-    def last_edited_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def last_edited_at(self) -> datetime:
         self._completeIfNotSet(self._last_edited_at)
         return self._last_edited_at.value
 
     @property
-    def node_id(self):
-        """
-        :type: string
-        """
+    def node_id(self) -> str:
         self._completeIfNotSet(self._node_id)
         return self._node_id.value
 
     @property
-    def number(self):
-        """
-        :type: integer
-        """
+    def number(self) -> int:
         self._completeIfNotSet(self._number)
         return self._number.value
 
     @property
-    def pinned(self):
-        """
-        :type: bool
-        """
+    def pinned(self) -> bool:
         self._completeIfNotSet(self._pinned)
         return self._pinned.value
 
     @property
-    def private(self):
-        """
-        :type: bool
-        """
+    def private(self) -> bool:
         self._completeIfNotSet(self._private)
         return self._private.value
 
     @property
-    def team_url(self):
-        """
-        :type: string
-        """
+    def team_url(self) -> str:
         self._completeIfNotSet(self._team_url)
         return self._team_url.value
 
     @property
-    def title(self):
-        """
-        :type: string
-        """
+    def title(self) -> str:
         self._completeIfNotSet(self._title)
         return self._title.value
 
     @property
-    def updated_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def updated_at(self) -> datetime:
         self._completeIfNotSet(self._updated_at)
         return self._updated_at.value
 
     @property
-    def url(self):
-        """
-        :type: string
-        """
+    def url(self) -> str:
         self._completeIfNotSet(self._url)
         return self._url.value
 
-    def _initAttributes(self):
-        self._author = github.GithubObject.NotSet
-        self._body = github.GithubObject.NotSet
-        self._body_html = github.GithubObject.NotSet
-        self._body_version = github.GithubObject.NotSet
-        self._comments_count = github.GithubObject.NotSet
-        self._comments_url = github.GithubObject.NotSet
-        self._created_at = github.GithubObject.NotSet
-        self._html_url = github.GithubObject.NotSet
-        self._last_edited_at = github.GithubObject.NotSet
-        self._node_id = github.GithubObject.NotSet
-        self._number = github.GithubObject.NotSet
-        self._pinned = github.GithubObject.NotSet
-        self._private = github.GithubObject.NotSet
-        self._team_url = github.GithubObject.NotSet
-        self._title = github.GithubObject.NotSet
-        self._updated_at = github.GithubObject.NotSet
-        self._url = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "author" in attributes:  # pragma no branch
-            self._author = self._makeClassAttribute(
-                github.NamedUser.NamedUser, attributes["author"]
-            )
+            self._author = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["author"])
         if "body" in attributes:  # pragma no branch
             self._body = self._makeStringAttribute(attributes["body"])
         if "body_html" in attributes:  # pragma no branch
@@ -210,9 +159,7 @@ class TeamDiscussion(github.GithubObject.CompletableGithubObject):
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "last_edited_at" in attributes:  # pragma no branch
-            self._last_edited_at = self._makeDatetimeAttribute(
-                attributes["last_edited_at"]
-            )
+            self._last_edited_at = self._makeDatetimeAttribute(attributes["last_edited_at"])
         if "node_id" in attributes:  # pragma no branch
             self._node_id = self._makeStringAttribute(attributes["node_id"])
         if "number" in attributes:  # pragma no branch
