@@ -19,117 +19,86 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+from __future__ import annotations
 
-import github.GithubObject
+from datetime import datetime
+from typing import Any
+
+from github.GithubObject import Attribute, NonCompletableGithubObject, NotSet
 
 
-class Topic(github.GithubObject.NonCompletableGithubObject):
+class Topic(NonCompletableGithubObject):
     """
-    This class represents topics as used by https://github.com/topics. The object reference can be found here https://developer.github.com/v3/search/#search-topics
+    This class represents topics as used by https://github.com/topics. The object reference can be found here https://docs.github.com/en/rest/reference/search#search-topics
     """
 
-    def __repr__(self):
+    def _initAttributes(self) -> None:
+        self._name: Attribute[str] = NotSet
+        self._display_name: Attribute[str] = NotSet
+        self._short_description: Attribute[str] = NotSet
+        self._description: Attribute[str] = NotSet
+        self._created_by: Attribute[str] = NotSet
+        self._released: Attribute[str] = NotSet
+        self._created_at: Attribute[datetime] = NotSet
+        self._updated_at: Attribute[datetime] = NotSet
+        self._featured: Attribute[bool] = NotSet
+        self._curated: Attribute[bool] = NotSet
+        self._score: Attribute[float] = NotSet
+
+    def __repr__(self) -> str:
         return self.get__repr__({"name": self._name.value})
 
     @property
-    def name(self):
-        """
-        :type: string
-        """
+    def name(self) -> str:
         return self._name.value
 
     @property
-    def display_name(self):
-        """
-        :type: string
-        """
+    def display_name(self) -> str:
         return self._display_name.value
 
     @property
-    def short_description(self):
-        """
-        :type: string
-        """
+    def short_description(self) -> str:
         return self._short_description.value
 
     @property
-    def description(self):
-        """
-        :type: string
-        """
+    def description(self) -> str:
         return self._description.value
 
     @property
-    def created_by(self):
-        """
-        :type: string
-        """
+    def created_by(self) -> str:
         return self._created_by.value
 
     @property
-    def released(self):
-        """
-        :type: string
-        """
+    def released(self) -> str:
         return self._released.value
 
     @property
-    def created_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def created_at(self) -> datetime:
         return self._created_at.value
 
     @property
-    def updated_at(self):
-        """
-        :type: datetime.datetime
-        """
+    def updated_at(self) -> datetime:
         return self._updated_at.value
 
     @property
-    def featured(self):
-        """
-        :type: bool
-        """
+    def featured(self) -> bool:
         return self._featured.value
 
     @property
-    def curated(self):
-        """
-        :type: bool
-        """
+    def curated(self) -> bool:
         return self._curated.value
 
     @property
-    def score(self):
-        """
-        :type: float
-        """
+    def score(self) -> float:
         return self._score.value
 
-    def _initAttributes(self):
-        self._name = github.GithubObject.NotSet
-        self._display_name = github.GithubObject.NotSet
-        self._short_description = github.GithubObject.NotSet
-        self._description = github.GithubObject.NotSet
-        self._created_by = github.GithubObject.NotSet
-        self._released = github.GithubObject.NotSet
-        self._created_at = github.GithubObject.NotSet
-        self._updated_at = github.GithubObject.NotSet
-        self._featured = github.GithubObject.NotSet
-        self._curated = github.GithubObject.NotSet
-        self._score = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "name" in attributes:  # pragma no branch
             self._name = self._makeStringAttribute(attributes["name"])
         if "display_name" in attributes:  # pragma no branch
             self._display_name = self._makeStringAttribute(attributes["display_name"])
         if "short_description" in attributes:  # pragma no branch
-            self._short_description = self._makeStringAttribute(
-                attributes["short_description"]
-            )
+            self._short_description = self._makeStringAttribute(attributes["short_description"])
         if "description" in attributes:  # pragma no branch
             self._description = self._makeStringAttribute(attributes["description"])
         if "created_by" in attributes:  # pragma no branch
